__title__ = "py-tools-wd"
__description__ = "wd py tools"
__url__ = "https://github.com/pgcomb/wd_tools_py"
__version__ = "0.1.12"
# __build__ = 0x023202
__author__ = ["Wang Dongxu", "Ma xiaohui"]
__author_email__ = ["wangdongxudyx@163.com", ""]
__license__ = "Apache-2.0"
# __copyright__ = "Copyright Kenneth Reitz"
# __cake__ = "\u2728 \U0001f370 \u2728"
